@@ -13,9 +13,9 @@ proc DS9Def {} {
     }
 
     # Must be major,minor
-    set ds9(version) {8.3}
+    set ds9(version) {8.4}
     # For display purposes only
-    set ds9(version,display) {8.3}
+    set ds9(version,display) {8.4}
 
     set ds9(visual) {}
     set ds9(depth) 8
@@ -55,14 +55,6 @@ proc DS9Def {} {
 	    set ds9(times) times
 	}
     }
-    set ds9(main) {}
-    set ds9(image) {}
-    set ds9(canvas) {}
-    set ds9(panel) {}
-    set ds9(info) {}
-    set ds9(panner) {}
-    set ds9(magnifier) {}
-    set ds9(buttons) {}
 
     set ds9(frames) {}
     set ds9(seq) 1
@@ -82,7 +74,7 @@ proc DS9Def {} {
     }
     set ds9(menu,size,frame,goto) [expr $ds9(menu,start)+0]
     set ds9(menu,size,frame,active) [expr $ds9(menu,start)+3]
-    set ds9(menu,size,analysis) [expr $ds9(menu,start)+36]
+    set ds9(menu,size,analysis) [expr $ds9(menu,start)+34]
     set ds9(menu,size,wrap) 20
 
     set ds9(display) single
@@ -174,6 +166,8 @@ proc DS9Def {} {
     set pds9(language,name) [LanguageToName $pds9(language)]
     set pds9(language,dir) {}
 
+    set pds9(infobox,filenametype) {root base}
+
     set pds9(theme) default
 }
 
@@ -216,6 +210,8 @@ package require base64
 package require ftp
 package require math::fuzzy
 
+package require tooltip
+
 package require tkcon
 package require Tkblt
 package require Tls
@@ -364,6 +360,7 @@ DebugDef
 ESODef
 ExamineDef
 ExportDef
+FadeDef
 FPDef
 GraphDef
 GridDef
@@ -373,6 +370,7 @@ HTTPDef
 HVDef
 IExamDef
 IISDef
+IllustrateDef
 MagnifierDef
 MarkerDef
 MaskDef
@@ -515,7 +513,7 @@ if {$ds9(prefs)} {
     LoadPrefs
 }
 
-# set fonts
+# set fonts, before init and realize
 SetDefaultFont false
 SetDefaultTextFont false
 
@@ -555,6 +553,9 @@ CreateColorbar
 
 # Create other parts of the display
 CreateMenuBar
+CreateHeader
+# come before panner/magnifer
+CreateIcons
 CreateInfoPanel
 CreatePanner
 CreateMagnifier
@@ -616,8 +617,13 @@ if {$pds9(xpa)} {
 # we want to see something before any fits files are loaded
 ProcessCommandLine
 
+# set fonts again
+# fonts can be set in commandline -restore
+SetDefaultFont true
+SetDefaultTextFont true
+
 # Initialize IIS
-# after command line options to set port/fifo/unix...
+# after command line options to set port/fifo/unix
 catch {IISInit}
 
 # any os events received?
