@@ -26,6 +26,9 @@ proc CreateMenuBar {} {
     $ds9(mb) add cascade -label [msgcat::mc {Color}] -menu $ds9(mb).color
     $ds9(mb) add cascade -label [msgcat::mc {Region}] -menu $ds9(mb).region
     $ds9(mb) add cascade -label [msgcat::mc {WCS}] -menu $ds9(mb).wcs
+    # on purpose
+    $ds9(mb) add cascade -label [msgcat::mc {Illustrate}] \
+	-menu $ds9(mb).illustrate -state disabled
     $ds9(mb) add cascade -label [msgcat::mc {Analysis}] -menu $ds9(mb).analysis
 
     FileMainMenu
@@ -38,6 +41,7 @@ proc CreateMenuBar {} {
     ColorMainMenu
     RegionMainMenu
     WCSMainMenu
+    IllustrateMainMenu
     AnalysisMainMenu
     HelpMainMenu
 
@@ -591,7 +595,7 @@ proc ColorMenu {w varname color cmd} {
     $w add radiobutton -label [msgcat::mc {Yellow}] \
 	-variable ${varname}($color) -value yellow -command $cmd
     $w add separator
-    $w add command -label "[msgcat::mc {Other Color}]..." \
+    $w add command -label [msgcat::mc {Other Color}] \
 	-command [list ColorMenuOther $varname $color $cmd]
 }
 
@@ -600,6 +604,10 @@ proc ColorMenuOther {varname color cmd} {
     global $varname
 
     if {[EntryDialog [msgcat::mc {Color}] [msgcat::mc {Enter Color}] 20 ${varname}($color)]} {
+	# we might have been closed while waiting
+	if {![info exists $varname]} {
+	    return
+	}
 	eval $cmd
     }
 }
@@ -612,6 +620,44 @@ proc ColorMenuButton {w varname color cmd} {
     ColorMenu $w.menu $varname $color $cmd
 }
 
+# ColorFillMenu
+proc ColorFillMenu {w varname color fill cmd1 cmd2} {
+    upvar #0 $varname var
+    global $varname
+
+    ThemeMenu $w
+    $w add radiobutton -label [msgcat::mc {Black}] \
+	-variable ${varname}($color) -value black -command $cmd1
+    $w add radiobutton -label [msgcat::mc {White}] \
+	-variable ${varname}($color) -value white -command $cmd1
+    $w add radiobutton -label [msgcat::mc {Red}] \
+	-variable ${varname}($color) -value red -command $cmd1
+    $w add radiobutton -label [msgcat::mc {Green}] \
+	-variable ${varname}($color) -value green -command $cmd1
+    $w add radiobutton -label [msgcat::mc {Blue}] \
+	-variable ${varname}($color) -value blue -command $cmd1
+    $w add radiobutton -label [msgcat::mc {Cyan}] \
+	-variable ${varname}($color) -value cyan -command $cmd1
+    $w add radiobutton -label [msgcat::mc {Magenta}] \
+	-variable ${varname}($color) -value magenta -command $cmd1
+    $w add radiobutton -label [msgcat::mc {Yellow}] \
+	-variable ${varname}($color) -value yellow -command $cmd1
+    $w add separator
+    $w add command -label [msgcat::mc {Other Color}] \
+	-command [list ColorMenuOther $varname $color $cmd1]
+    $w add separator
+    $w add checkbutton -label [msgcat::mc {Fill}] \
+	-variable ${varname}($fill) -command $cmd2
+}
+
+proc ColorFillMenuButton {w varname color fill cmd1 cmd2} {
+    upvar #0 $varname var
+    global $varname
+    
+    ttk::menubutton $w -textvariable ${varname}($color) -menu $w.menu
+    ColorFillMenu $w.menu $varname $color $fill $cmd1 $cmd
+}
+
 # FontMenu
 proc FontMenu {w varname font size weight slant cmd} {
     upvar #0 $varname var
@@ -646,7 +692,7 @@ proc FontMenu {w varname font size weight slant cmd} {
     $w add radiobutton -label {72} -variable ${varname}($size) \
 	-value 72 -command $cmd
     $w add separator
-    $w add command -label "[msgcat::mc {Other Font Size}]..." \
+    $w add command -label [msgcat::mc {Other Font Size}] \
 	-command [list FontMenuSize $varname $size $cmd]
     $w add separator
     $w add radiobutton -label [msgcat::mc {Normal}] \
@@ -665,6 +711,10 @@ proc FontMenuSize {varname size cmd} {
     global $varname
 
     if {[EntryDialog [msgcat::mc {Font Size}] [msgcat::mc {Enter Font Size}] 20 ${varname}($size)]} {
+	# we might have been closed while waiting
+	if {![info exists $varname]} {
+	    return
+	}
 	eval $cmd
     }
 }
@@ -677,6 +727,30 @@ proc FontMenuButton {w varname font size weight slant cmd} {
     FontMenu $w.menu $varname $font $size $weight $slant $cmd
 }
 
+# WidthMenu
+proc WidthMenu {w varname width cmd} {
+    upvar #0 $varname var
+    global $varname
+
+    ThemeMenu $w
+    $w add radiobutton -label {1} -variable ${varname}($width) \
+	-value 1 -command $cmd
+    $w add radiobutton -label {2} -variable ${varname}($width) \
+	-value 2 -command $cmd
+    $w add radiobutton -label {3} -variable ${varname}($width) \
+	-value 3 -command $cmd
+    $w add radiobutton -label {4} -variable ${varname}($width) \
+	-value 4 -command $cmd
+}
+
+proc WidthMenuButton {w varname width dash cmd} {
+    upvar #0 $varname var
+    global $varname
+    
+    ttk::menubutton $w -textvariable ${varname}($width) -menu $w.menu
+    WidthMenu $w.menu $varname $width $cmd
+}
+
 # WidthDashMenu
 proc WidthDashMenu {w varname width dash cmd1 cmd2} {
     upvar #0 $varname var
@@ -691,12 +765,9 @@ proc WidthDashMenu {w varname width dash cmd1 cmd2} {
 	-value 3 -command $cmd1
     $w add radiobutton -label {4} -variable ${varname}($width) \
 	-value 4 -command $cmd1
-
-    if {$dash != {}} {
-	$w add separator
-	$w add checkbutton -label [msgcat::mc {Dash}] \
-	    -variable ${varname}($dash) -command $cmd2
-    }
+    $w add separator
+    $w add checkbutton -label [msgcat::mc {Dash}] \
+	-variable ${varname}($dash) -command $cmd2
 }
 
 proc WidthDashMenuButton {w varname width dash cmd1 cmd2} {
@@ -726,16 +797,8 @@ proc PrefsDialogMenu {} {
     PrefsDialogColorMenu $w.menu
     PrefsDialogRegionMenu $w.menu
     PrefsDialogWCSMenu $w.menu
+    PrefsDialogIllustrateMenu $w.menu
     PrefsDialogAnalysisMenu $w.menu
     PrefsDialogHelpMenu $w.menu
 }
 
-proc ConfigureButtons {menu state} {
-    global ds9
-    global pbuttons
-
-    foreach aa [array names pbuttons "$menu,*"] {
-	set bb [lindex [split $aa {,}] 1]
-	$ds9(buttons).$menu.$bb configure -state $state
-    }
-}
