@@ -11,7 +11,7 @@ proc RegionMainMenu {} {
     global marker
 
     ThemeMenu $ds9(mb).region
-    $ds9(mb).region add command -label "[msgcat::mc {Get Information}]..." \
+    $ds9(mb).region add command -label [msgcat::mc {Get Information}] \
 	-command MarkerInfo
     $ds9(mb).region add separator
     $ds9(mb).region add cascade -label [msgcat::mc {Shape}] \
@@ -34,41 +34,45 @@ proc RegionMainMenu {} {
     $ds9(mb).region add separator
     $ds9(mb).region add command -label [msgcat::mc {Centroid}] \
 	-command MarkerCentroid
+    $ds9(mb).region add separator
+    $ds9(mb).region add command -label [msgcat::mc {New Group}] \
+	-command GroupCreate
+    $ds9(mb).region add command -label [msgcat::mc {Groups}] \
+	-command GroupDialog
+    $ds9(mb).region add separator
+    $ds9(mb).region add command -label [msgcat::mc {All}] \
+	-command MarkerSelectAll -accelerator "${ds9(ctrl)}A"
+    $ds9(mb).region add command -label [msgcat::mc {None}] \
+	-command MarkerSelectNone -accelerator "${ds9(shiftctrl)}A"
+    $ds9(mb).region add command -label [msgcat::mc {Invert}] \
+	-command MarkerSelectInvert
+    $ds9(mb).region add command -label [msgcat::mc {Front}] \
+	-command MarkerSelectFront
+    $ds9(mb).region add command -label [msgcat::mc {Back}] \
+	-command MarkerSelectBack
+    $ds9(mb).region add separator
     $ds9(mb).region add command -label [msgcat::mc {Move to Front}] \
 	-command MarkerFront
     $ds9(mb).region add command -label [msgcat::mc {Move to Back}] \
 	-command MarkerBack
     $ds9(mb).region add separator
-    $ds9(mb).region add command -label [msgcat::mc {New Group}] \
-	-command GroupCreate
-    $ds9(mb).region add command -label "[msgcat::mc {Groups}]..." \
-	-command GroupDialog
-    $ds9(mb).region add separator
-    $ds9(mb).region add command -label [msgcat::mc {Select All}] \
-	-command MarkerSelectAll -accelerator "${ds9(ctrl)}A"
-    $ds9(mb).region add command -label [msgcat::mc {Select None}] \
-	-command MarkerUnselectAll -accelerator "${ds9(shiftctrl)}A"
-    $ds9(mb).region add command -label [msgcat::mc {Invert Selection}] \
-	-command MarkerSelectInvert
-    $ds9(mb).region add separator
-    $ds9(mb).region add command -label [msgcat::mc {Save Selected Regions}] \
+    $ds9(mb).region add command -label [msgcat::mc {Save Selection}] \
 	-command [list MarkerSave select]
-    $ds9(mb).region add command -label [msgcat::mc {List Selected Regions}] \
-	-command [list MarkerList select]
-    $ds9(mb).region add command -label [msgcat::mc {Delete Selected Regions}] \
-	-command [list MarkerDelete select]
+    $ds9(mb).region add command -label [msgcat::mc {List Selection}] \
+	-command MarkerListSelect
+    $ds9(mb).region add command -label [msgcat::mc {Delete Selection}] \
+	-command MarkerDeleteSelect
     $ds9(mb).region add separator
-    $ds9(mb).region add command -label "[msgcat::mc {Open Regions}]..." \
+    $ds9(mb).region add command -label [msgcat::mc {Open}] \
 	-command MarkerLoad
-    $ds9(mb).region add command -label "[msgcat::mc {Save Regions}]..." \
+    $ds9(mb).region add command -label [msgcat::mc {Save}] \
 	-command [list MarkerSave {}]
-    $ds9(mb).region add command -label "[msgcat::mc {List Regions}]..." \
-	-command [list MarkerList {}]
-    $ds9(mb).region add command -label [msgcat::mc {Delete Regions}] \
-	-command [list MarkerDelete {}]
+    $ds9(mb).region add command -label [msgcat::mc {List}] \
+	-command MarkerListAll
     $ds9(mb).region add separator
-    $ds9(mb).region add command \
-	-label "[msgcat::mc {Delete and Open Regions}]..." \
+    $ds9(mb).region add command -label [msgcat::mc {Delete All}] \
+	-command MarkerDeleteAll
+    $ds9(mb).region add command -label [msgcat::mc {Delete All and Open}] \
 	-command MarkerDeleteLoad
     $ds9(mb).region add separator
     $ds9(mb).region add cascade -label [msgcat::mc {Region Parameters}] \
@@ -144,12 +148,13 @@ proc RegionMainMenu {} {
     CreateFOVMenu
 
     ThemeMenu $ds9(mb).region.template
-    $ds9(mb).region.template add command -label "[msgcat::mc {Open}]..." \
+    $ds9(mb).region.template add command -label [msgcat::mc {Open}] \
 	-command OpenTemplateMarker
-    $ds9(mb).region.template add command -label "[msgcat::mc {Save}]..." \
+    $ds9(mb).region.template add command -label [msgcat::mc {Save}] \
 	-command SaveAsTemplateMarker
 
-    ColorMenu $ds9(mb).region.color marker color MarkerColor
+    ColorFillMenu $ds9(mb).region.color marker color fill \
+	MarkerColor [list MarkerProp fill]
     WidthDashMenu $ds9(mb).region.width marker width dash \
 	MarkerWidth [list MarkerProp dash]
 
@@ -207,12 +212,12 @@ proc RegionMainMenu {} {
 	-label [msgcat::mc {Auto Centroid}] \
 	-variable marker(centroid,auto) -command MarkerCentroidAuto
     $ds9(mb).region.params add command \
-	-label "[msgcat::mc {Centroid Parameters}]..." \
+	-label [msgcat::mc {Centroid Parameters}] \
 	-command CentroidDialog
 
     # Bindings
     bind $ds9(top) <<SelectAll>> MarkerSelectAll
-    bind $ds9(top) <<SelectNone>> MarkerUnselectAll
+    bind $ds9(top) <<SelectNone>> MarkerSelectNone
 }
 
 proc PrefsDialogRegionMenu {w} {
@@ -293,7 +298,7 @@ proc PrefsDialogRegionMenu {w} {
     $m.shape.point add radiobutton -label [msgcat::mc {BoxCircle}]\
 	-variable pmarker(shape) -value {boxcircle point}
 
-    ColorMenu $m.color pmarker color {}
+    ColorFillMenu $m.color pmarker color fill {} {}
     WidthDashMenu $m.width pmarker width dash {} {}
 
     ThemeMenu $m.properties
@@ -421,8 +426,8 @@ proc PrefsDialogRegion {} {
     grid $f.ititle $f.iteration $f.rtitle $f.radius -padx 2 -pady 2 -sticky w
     # Plots
     set f [ttk::labelframe $w.region.plot -text [msgcat::mc {Auto Plot}]]
-    ttk::checkbutton $f.2d -text [msgcat::mc {2D}] -variable pmarker(plot2d)
-    ttk::checkbutton $f.3d -text [msgcat::mc {3D}] -variable pmarker(plot3d)
+    ttk::checkbutton $f.2d -text [msgcat::mc {2d}] -variable pmarker(plot2d)
+    ttk::checkbutton $f.3d -text [msgcat::mc {3d}] -variable pmarker(plot3d)
     ttk::checkbutton $f.stats -text [msgcat::mc {Statistics}] \
 	-variable pmarker(stats)
 
@@ -466,6 +471,20 @@ proc PrefsDialogRegion {} {
     grid $f.title $f.radius1 $f.unit -padx 2 -pady 2 -sticky w
     grid $f.title2 $f.radius2 $f.unit2 -padx 2 -pady 2 -sticky w
 
+    # Polygon
+    set f [ttk::labelframe $w.region.polygon -text [msgcat::mc {Polygon}]]
+
+    ttk::label $f.title -text "Width"
+    ttk::entry $f.width -textvariable pmarker(polygon,width) -width 10 
+    ttk::label $f.unit -text [msgcat::mc {Image}]
+    
+    ttk::label $f.title2 -text "Height"
+    ttk::entry $f.height -textvariable pmarker(polygon,height) -width 10 
+    ttk::label $f.unit2 -text [msgcat::mc {Image}]
+
+    grid $f.title $f.width $f.unit -padx 2 -pady 2 -sticky w
+    grid $f.title2 $f.height $f.unit2 -padx 2 -pady 2 -sticky w
+
     # Projection
     set f [ttk::labelframe $w.region.projection -text [msgcat::mc {Projection}]]
 
@@ -487,7 +506,7 @@ proc PrefsDialogRegion {} {
     pack $w.region.format $w.region.dformat $w.region.epsilon \
 	$w.region.centroid $w.region.plot \
 	$w.region.circle $w.region.ellipse \
-	$w.region.box $w.region.projection $w.region.point \
+	$w.region.box $w.region.polygon $w.region.projection $w.region.point \
 	-side top -fill both -expand true
 }
 
@@ -716,7 +735,7 @@ proc ButtonsRegionDef {} {
 	region,group 0
 	region,all 1
 	region,none 1
-	region,invert 0
+	region,invert 1
 	region,saveselect 0
 	region,listselect 0
 	region,deleteselect 0
@@ -742,58 +761,58 @@ proc CreateButtonsRegion {} {
 
     RadioButton $ds9(buttons).region.circle \
 	[string tolower [msgcat::mc {Circle}]] \
-	marker(shape) circle {}
+	marker shape circle {}
     RadioButton $ds9(buttons).region.ellipse \
 	[string tolower [msgcat::mc {Ellipse}]] \
-	marker(shape) ellipse {}
+	marker shape ellipse {}
     RadioButton $ds9(buttons).region.box \
 	[string tolower [msgcat::mc {Box}]] \
-	marker(shape) box {}
+	marker shape box {}
     RadioButton $ds9(buttons).region.polygon \
 	[string tolower [msgcat::mc {Polygon}]] \
-	marker(shape) polygon {}
+	marker shape polygon {}
     RadioButton $ds9(buttons).region.line \
 	[string tolower [msgcat::mc {Line}]] \
-	marker(shape) line {}
+	marker shape line {}
     RadioButton $ds9(buttons).region.vector \
 	[string tolower [msgcat::mc {Vector}]] \
-	marker(shape) vector {}
+	marker shape vector {}
     RadioButton $ds9(buttons).region.projection \
 	[string tolower [msgcat::mc {Projection}]] \
-	marker(shape) projection {}
+	marker shape projection {}
     RadioButton $ds9(buttons).region.segment \
 	[string tolower [msgcat::mc {Segment}]] \
-	marker(shape) segment {}
+	marker shape segment {}
     RadioButton $ds9(buttons).region.text \
 	[string tolower [msgcat::mc {Text}]] \
-	marker(shape) text {}
+	marker shape text {}
     RadioButton $ds9(buttons).region.point \
 	[string tolower [msgcat::mc {Point}]] \
-	marker(shape) {circle point} {}
+	marker shape {circle point} {}
     RadioButton $ds9(buttons).region.ruler \
 	[string tolower [msgcat::mc {Ruler}]] \
-	marker(shape) ruler {}
+	marker shape ruler {}
     RadioButton $ds9(buttons).region.compass \
 	[string tolower [msgcat::mc {Compass}]] \
-	marker(shape) compass {}
+	marker shape compass {}
     RadioButton $ds9(buttons).region.annulus \
 	[string tolower [msgcat::mc {Annulus}]] \
-	marker(shape) annulus {}
+	marker shape annulus {}
     RadioButton $ds9(buttons).region.ellipseannulus \
 	[string tolower [msgcat::mc {Elliptical Annulus}]] \
-	marker(shape) ellipseannulus {}
+	marker shape ellipseannulus {}
     RadioButton $ds9(buttons).region.boxannulus \
 	[string tolower [msgcat::mc {Box Annulus}]] \
-	marker(shape) boxannulus {}
+	marker shape boxannulus {}
     RadioButton $ds9(buttons).region.panda \
 	[string tolower [msgcat::mc {Panda}]] \
-	marker(shape) panda {}
+	marker shape panda {}
     RadioButton $ds9(buttons).region.epanda \
 	[string tolower [msgcat::mc {Ellipse Panda}]] \
-	marker(shape) epanda {}
+	marker shape epanda {}
     RadioButton $ds9(buttons).region.bpanda \
 	[string tolower [msgcat::mc {Box Panda}]] \
-	marker(shape) bpanda {}
+	marker shape bpanda {}
 
     ButtonButton $ds9(buttons).region.create \
 	[string tolower [msgcat::mc {Composite}]] CompositeCreate
@@ -820,38 +839,38 @@ proc CreateButtonsRegion {} {
     ButtonButton $ds9(buttons).region.all \
 	[string tolower [msgcat::mc {All}]] MarkerSelectAll
     ButtonButton $ds9(buttons).region.none \
-	[string tolower [msgcat::mc {None}]] MarkerUnselectAll
+	[string tolower [msgcat::mc {None}]] MarkerSelectNone
     ButtonButton $ds9(buttons).region.invert \
 	[string tolower [msgcat::mc {Invert}]] MarkerSelectInvert
 
     ButtonButton $ds9(buttons).region.saveselect \
-	[string tolower [msgcat::mc {Save Select}]] [list MarkerSave select]
+	[string tolower [msgcat::mc {Save Select}]] \
+	[list MarkerSave select]
     ButtonButton $ds9(buttons).region.listselect \
-	[string tolower [msgcat::mc {List Select}]] [list MarkerList select]
+	[string tolower [msgcat::mc {List Select}]] MarkerListSelect
     ButtonButton $ds9(buttons).region.deleteselect \
-	[string tolower [msgcat::mc {Delete Select}]] [list MarkerDelete select]
+	[string tolower [msgcat::mc {Delete Select}]] MarkerDeleteSelect
 
     ButtonButton $ds9(buttons).region.load \
 	[string tolower [msgcat::mc {Open}]] MarkerLoad
     ButtonButton $ds9(buttons).region.save \
 	[string tolower [msgcat::mc {Save}]] [list MarkerSave {}]
     ButtonButton $ds9(buttons).region.list \
-	[string tolower [msgcat::mc {List}]] [list MarkerList {}]
+	[string tolower [msgcat::mc {List}]] MarkerListAll
     ButtonButton $ds9(buttons).region.delete \
-	[string tolower [msgcat::mc {Delete}]] [list MarkerDelete {}]
-    
+	[string tolower [msgcat::mc {Delete All}]] MarkerDeleteAll
     ButtonButton $ds9(buttons).region.deleteload \
-	[string tolower [msgcat::mc {Delete Load}]] MarkerDeleteLoad
+	[string tolower [msgcat::mc {Delete All Load}]] MarkerDeleteLoad
 
     CheckButton $ds9(buttons).region.show \
 	[string tolower [msgcat::mc {Show}]] \
-	marker(show) MarkerShow
+	marker show MarkerShow
     CheckButton $ds9(buttons).region.showtext \
 	[string tolower [msgcat::mc {Show Text}]] \
-	marker(show,text) MarkerShowText
+	marker show,text MarkerShowText
     CheckButton $ds9(buttons).region.autocentroid \
 	[string tolower [msgcat::mc {Auto Centroid}]] \
-	marker(centroid,auto) MarkerCentroidAuto
+	marker centroid,auto MarkerCentroidAuto
 
     set buttons(region) "
         $ds9(buttons).region.info pbuttons(region,info)
@@ -907,7 +926,7 @@ proc PrefsDialogButtonbarRegion {f} {
     
     set m $f.menu
     ThemeMenu $m
-    $m add checkbutton -label "[msgcat::mc {Get Information}]..." \
+    $m add checkbutton -label [msgcat::mc {Get Information}] \
 	-variable pbuttons(region,info) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
@@ -928,44 +947,44 @@ proc PrefsDialogButtonbarRegion {f} {
     $m add checkbutton -label [msgcat::mc {New Group}] \
 	-variable pbuttons(region,newgroup) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label "[msgcat::mc {Groups}]..." \
+    $m add checkbutton -label [msgcat::mc {Groups}] \
 	-variable pbuttons(region,group) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
-    $m add checkbutton -label [msgcat::mc {Select All}] \
+    $m add checkbutton -label [msgcat::mc {All}] \
 	-variable pbuttons(region,all) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label [msgcat::mc {Select None}] \
+    $m add checkbutton -label [msgcat::mc {None}] \
 	-variable pbuttons(region,none) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label [msgcat::mc {Invert Selection}] \
+    $m add checkbutton -label [msgcat::mc {Invert}] \
 	-variable pbuttons(region,invert) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
-    $m add checkbutton -label [msgcat::mc {Save Selected Regions}] \
+    $m add checkbutton -label [msgcat::mc {Save Selection}] \
 	-variable pbuttons(region,saveselect) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label [msgcat::mc {List Selected Regions}] \
+    $m add checkbutton -label [msgcat::mc {List Selection}] \
 	-variable pbuttons(region,listselect) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label [msgcat::mc {Delete Selected Regions}] \
+    $m add checkbutton -label [msgcat::mc {Delete Selection}] \
 	-variable pbuttons(region,deleteselect) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Open Regions}]..." \
+    $m add checkbutton -label [msgcat::mc {Open}] \
 	-variable pbuttons(region,load) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label "[msgcat::mc {Save Regions}]..." \
+    $m add checkbutton -label [msgcat::mc {Save}] \
 	-variable pbuttons(region,save) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label "[msgcat::mc {List Regions}]..." \
+    $m add checkbutton -label [msgcat::mc {List}] \
 	-variable pbuttons(region,list) \
 	-command {UpdateButtons buttons(region)}
-    $m add checkbutton -label [msgcat::mc {Delete Regions}] \
+    $m add separator
+    $m add checkbutton -label [msgcat::mc {Delete All}] \
 	-variable pbuttons(region,delete) \
 	-command {UpdateButtons buttons(region)}
-    $m add separator
-    $m add checkbutton -label "[msgcat::mc {Delete and Open Regions}]..." \
+    $m add checkbutton -label [msgcat::mc {Delete All and Open}] \
 	-variable pbuttons(region,deleteload) \
 	-command {UpdateButtons buttons(region)}
     $m add separator
@@ -1040,10 +1059,10 @@ proc PrefsDialogButtonbarRegion {f} {
 	-command {UpdateButtons buttons(region)}
 
     ThemeMenu $m.template
-    $m.template add checkbutton -label "[msgcat::mc {Open}]..." \
+    $m.template add checkbutton -label [msgcat::mc {Open}] \
 	-variable pbuttons(region,loadtemplate) \
 	-command {UpdateButtons buttons(region)}
-    $m.template add checkbutton -label "[msgcat::mc {Save}]..." \
+    $m.template add checkbutton -label [msgcat::mc {Save}] \
 	-variable pbuttons(region,savetemplate) \
 	-command {UpdateButtons buttons(region)}
 
@@ -1071,186 +1090,92 @@ proc UpdateRegionMenu {} {
     set mm $ds9(mb).region
     set bb $ds9(buttons).region
 
-    if {$current(frame) != {}} {
-	$ds9(mb) entryconfig [msgcat::mc {Region}] -state normal
-	ConfigureButtons region normal
-
-	set marker(show) [$current(frame) get marker show]
-	set marker(show,text) [$current(frame) get marker show text]
-	set marker(centroid,auto) [$current(frame) get marker centroid auto]
-	set marker(centroid,radius) [$current(frame) get marker centroid radius]
-	set marker(centroid,iteration) \
-	    [$current(frame) get marker centroid iteration]
-	set marker(preserve) [$current(frame) get marker preserve]
-
-	switch -- $current(mode) {
-	    pointer -
-	    region {
-		if {[$current(frame) get marker select number] == 1} {
-		    set marker(color) \
-			[$current(frame) get marker color]
-		    set marker(width) \
-			[$current(frame) get marker width]
-		    set marker(dash) \
-			[$current(frame) get marker property dash]
-		    set marker(fixed) \
-			[$current(frame) get marker property fixed]
-		    set marker(edit) \
-			[$current(frame) get marker property edit]
-		    set marker(move) \
-			[$current(frame) get marker property move]
-		    set marker(rotate) \
-			[$current(frame) get marker property rotate]
-		    set marker(delete) \
-			[$current(frame) get marker property delete]
-		    set marker(include) \
-			[$current(frame) get marker property include]
-		    set marker(source) \
-			[$current(frame) get marker property source]
-
-		    set f [$current(frame) get marker font]
-
-		    set marker(font) [lindex $f 0]
-		    set marker(font,size) [lindex $f 1]
-		    set marker(font,weight) [lindex $f 2]
-		    set marker(font,slant) [lindex $f 3]
-		} else {
-		    # defaults
-		    set marker(color) $pmarker(color)
-		    set marker(width) $pmarker(width) 
-		    set marker(dash) $pmarker(dash) 
-		    set marker(fixed) $pmarker(fixed) 
-		    set marker(edit) $pmarker(edit) 
-		    set marker(move) $pmarker(move) 
-		    set marker(rotate) $pmarker(rotate) 
-		    set marker(delete) $pmarker(delete) 
-		    set marker(include) $pmarker(include) 
-		    set marker(source) $pmarker(source) 
-
-		    set marker(font) $pmarker(font) 
-		    set marker(font,size) $pmarker(font,size) 
-		    set marker(font,weight) $pmarker(font,weight) 
-		    set marker(font,slant) $pmarker(font,slant) 
-		}
-	    }
+    switch -- $current(mode) {
+	illustrate {
+	    $ds9(mb) entryconfig [msgcat::mc {Region}] -state disabled
+	    ConfigureButtons region disabled
+	    return
 	}
-
-	if {[$current(frame) has fits]} {
-	    $mm entryconfig "[msgcat::mc {Get Information}]..." -state normal
-
-	    $mm entryconfig [msgcat::mc {Composite Region}] -state normal
-	    $mm entryconfig [msgcat::mc {Instrument FOV}] -state normal
-	    $mm entryconfig [msgcat::mc {Template}] -state normal
-
-	    $mm entryconfig [msgcat::mc {Centroid}] -state normal
-	    $mm entryconfig [msgcat::mc {Move to Front}] -state normal
-	    $mm entryconfig [msgcat::mc {Move to Back}] -state normal
-
-	    $mm entryconfig [msgcat::mc {New Group}] -state normal
-	    $mm entryconfig "[msgcat::mc {Groups}]..." -state normal
-
-	    $mm entryconfig [msgcat::mc {Select All}] -state normal
-	    $mm entryconfig [msgcat::mc {Select None}] -state normal
-	    $mm entryconfig [msgcat::mc {Invert Selection}] -state normal
-
-	    $mm entryconfig [msgcat::mc {Delete Selected Regions}] -state normal
-
-	    $mm entryconfig "[msgcat::mc {Open Regions}]..." -state normal
-	    $mm entryconfig "[msgcat::mc {Save Regions}]..." -state normal
-	    $mm entryconfig "[msgcat::mc {List Regions}]..." -state normal
-	    $mm entryconfig [msgcat::mc {Delete Regions}] -state normal
-
-	    $mm entryconfig "[msgcat::mc {Delete and Open Regions}]..." \
-		-state normal
-
-	    $bb.info configure -state normal
-
-	    $bb.create configure -state normal
-	    $bb.dissolve configure -state normal
-
-	    $bb.loadtemplate configure -state normal
-	    $bb.savetemplate configure -state normal
-
-	    $bb.centroid configure -state normal
-	    $bb.front configure -state normal
-	    $bb.back configure -state normal
-
-	    $bb.newgroup configure -state normal
-	    $bb.group configure -state normal
-
-	    $bb.all configure -state normal
-	    $bb.none configure -state normal
-	    $bb.invert configure -state normal
-
-	    $bb.saveselect configure -state normal
-	    $bb.listselect configure -state normal
-	    $bb.deleteselect configure -state normal
-
-	    $bb.load configure -state normal
-	    $bb.save configure -state normal
-	    $bb.list configure -state normal
-	    $bb.delete configure -state normal
-
-	    $bb.deleteload configure -state normal
-	} else {
-	    $mm entryconfig "[msgcat::mc {Get Information}]..." -state disabled
-
-	    $mm entryconfig [msgcat::mc {Composite Region}] -state disabled
-	    $mm entryconfig [msgcat::mc {Instrument FOV}] -state disabled
-	    $mm entryconfig [msgcat::mc {Template}] -state disabled
-
-	    $mm entryconfig [msgcat::mc {Centroid}] -state disabled
-	    $mm entryconfig [msgcat::mc {Move to Front}] -state disabled
-	    $mm entryconfig [msgcat::mc {Move to Back}] -state disabled
-
-	    $mm entryconfig [msgcat::mc {New Group}] -state disabled
-	    $mm entryconfig "[msgcat::mc {Groups}]..." -state disabled
-
-	    $mm entryconfig [msgcat::mc {Select All}] -state disabled
-	    $mm entryconfig [msgcat::mc {Select None}] -state disabled
-	    $mm entryconfig [msgcat::mc {Invert Selection}] -state disabled
-
-	    $mm entryconfig [msgcat::mc {Delete Selected Regions}] -state disabled
-
-	    $mm entryconfig "[msgcat::mc {Open Regions}]..." -state disabled
-	    $mm entryconfig "[msgcat::mc {Save Regions}]..." -state disabled
-	    $mm entryconfig "[msgcat::mc {List Regions}]..." -state disabled
-	    $mm entryconfig [msgcat::mc {Delete Regions}] -state disabled
-
-	    $mm entryconfig "[msgcat::mc {Delete and Open Regions}]..." -state disabled
-
-	    $bb.info configure -state disabled
-
-	    $bb.create configure -state disabled
-	    $bb.dissolve configure -state disabled
-
-	    $bb.loadtemplate configure -state disabled
-	    $bb.savetemplate configure -state disabled
-
-	    $bb.centroid configure -state disabled
-	    $bb.front configure -state disabled
-	    $bb.back configure -state disabled
-
-	    $bb.newgroup configure -state disabled
-	    $bb.group configure -state disabled
-
-	    $bb.all configure -state disabled
-	    $bb.none configure -state disabled
-	    $bb.invert configure -state disabled
-
-	    $bb.saveselect configure -state disabled
-	    $bb.listselect configure -state disabled
-	    $bb.deleteselect configure -state disabled
-
-	    $bb.load configure -state disabled
-	    $bb.save configure -state disabled
-	    $bb.list configure -state disabled
-	    $bb.delete configure -state disabled
-
-	    $bb.deleteload configure -state disabled
+	default {
+	    $ds9(mb) entryconfig [msgcat::mc {Region}] -state normal
+	    ConfigureButtons region normal
 	}
-    } else {
+    }
+
+    if {$current(frame) == {}} {
 	$ds9(mb) entryconfig [msgcat::mc {Region}] -state disabled
 	ConfigureButtons region disabled
+	return
+    }
+    
+    if {![$current(frame) has fits]} {
+	$ds9(mb) entryconfig [msgcat::mc {Region}] -state disabled
+	ConfigureButtons region disabled
+	return
+    }
+    
+    set marker(show) [$current(frame) get marker show]
+    set marker(show,text) [$current(frame) get marker show text]
+    set marker(centroid,auto) [$current(frame) get marker centroid auto]
+    set marker(centroid,radius) [$current(frame) get marker centroid radius]
+    set marker(centroid,iteration) \
+	[$current(frame) get marker centroid iteration]
+    set marker(preserve) [$current(frame) get marker preserve]
+
+    switch -- $current(mode) {
+	pointer -
+	region {
+	    if {[$current(frame) get marker select number] == 1} {
+		set marker(color) \
+		    [$current(frame) get marker color]
+		set marker(fill) \
+		    [$current(frame) get marker property fill]
+		set marker(width) \
+		    [$current(frame) get marker width]
+		set marker(dash) \
+		    [$current(frame) get marker property dash]
+
+		set f [$current(frame) get marker font]
+		set marker(font) [lindex $f 0]
+		set marker(font,size) [lindex $f 1]
+		set marker(font,weight) [lindex $f 2]
+		set marker(font,slant) [lindex $f 3]
+
+		set marker(fixed) \
+		    [$current(frame) get marker property fixed]
+		set marker(edit) \
+		    [$current(frame) get marker property edit]
+		set marker(move) \
+		    [$current(frame) get marker property move]
+		set marker(rotate) \
+		    [$current(frame) get marker property rotate]
+		set marker(delete) \
+		    [$current(frame) get marker property delete]
+		set marker(include) \
+		    [$current(frame) get marker property include]
+		set marker(source) \
+		    [$current(frame) get marker property source]
+
+	    } else {
+		# defaults
+		set marker(color) $pmarker(color)
+		set marker(fill) $pmarker(fill) 
+		set marker(width) $pmarker(width) 
+		set marker(dash) $pmarker(dash) 
+
+		set marker(font) $pmarker(font) 
+		set marker(font,size) $pmarker(font,size) 
+		set marker(font,weight) $pmarker(font,weight) 
+		set marker(font,slant) $pmarker(font,slant) 
+
+		set marker(fixed) $pmarker(fixed) 
+		set marker(edit) $pmarker(edit) 
+		set marker(move) $pmarker(move) 
+		set marker(rotate) $pmarker(rotate) 
+		set marker(delete) $pmarker(delete) 
+		set marker(include) $pmarker(include) 
+		set marker(source) $pmarker(source) 
+	    }
+	}
     }
 }
