@@ -17,6 +17,7 @@ proc CurrentDef {} {
 
     set current(display) single
     set current(mode) none
+    set current(mode,illustrate) 0
     set current(zoom) {1 1}
     set current(rotate) 0
     set current(orient) none
@@ -75,7 +76,7 @@ proc UpdateDS9 {} {
 
     global debug
     if {$debug(tcl,update)} {
-	puts stderr "UpdateDS9 begin..."
+	puts stderr "UpdateDS9 begin"
     }
 
     UpdateFileMenu
@@ -88,6 +89,7 @@ proc UpdateDS9 {} {
     UpdateRegionMenu
     # wcs(system) set here
     UpdateWCSMenu 
+    UpdateIllustrateMenu
     UpdateAnalysisMenu
     UpdateAnalysisButtonbar
 
@@ -121,7 +123,7 @@ proc UpdateDS9 {} {
     UpdateColormapLevel
     
     if {$debug(tcl,update)} {
-	puts stderr "UpdateDS9 end...\n"
+	puts stderr "UpdateDS9 end\n"
     }
 }
 
@@ -161,7 +163,8 @@ proc UpdateMain {} {
 	crop -
 	examine -
 	iexam -
-	3d {}
+	3d -
+	illustrate {}
     }
 }
 
@@ -643,7 +646,7 @@ proc InitFilterCompiler {} {
     global env
     global argv0
 
-    # if the user did not explicitly specify one ...
+    # if the user did not explicitly specify one
     if {![info exists env(FILTER_CC)]} {
 	switch -- $ds9(wm) {
 	    x11 -
@@ -736,6 +739,40 @@ proc Sex2D {str} {
     return [expr $sign * (abs($degree)+($min/60.)+($sec/(60.*60.)))]
 }
 
+proc WarpCursor {which x y} {
+    global ds9
+
+    $which warp $x $y
+    # major kludge: macos warp does not generate motion event
+    switch $ds9(wm) {
+	x11 -
+	win32 {}
+	aqua {
+	    set foo [$which query cursor]
+	    set xx [expr [lindex $foo 0]+$x]
+	    set yy [expr [lindex $foo 1]+$y]
+	    event generate $ds9(canvas) <Motion> -x $xx -y $yy
+	}
+    }
+}
+
+proc WarpToCursor {which x y} {
+    global ds9
+
+    $which warp to $x $y
+    # major kludge: macos warp does not generate motion event
+    switch $ds9(wm) {
+	x11 -
+	win32 {}
+	aqua {
+	    set foo [$which query cursor]
+	    set xx [lindex $foo 0]
+	    set yy [lindex $foo 1]
+	    event generate $ds9(canvas) <Motion> -x $xx -y $yy
+	}
+    }
+}
+
 proc SetCursor {cursor} {
     global ds9
     global iis
@@ -814,7 +851,7 @@ proc AboutBoxDefault {} {
     canvas $f.c -background white -height 300 -width 500
     pack $f.c -fill both -expand true
     
-    set ed(sun) [image create photo -format gif -file $ds9(root)/doc/sun.gif]
+    set ed(sun) [image create photo -file $ds9(root)/doc/sun.png]
     
     $f.c create image 0 0 -image $ed(sun) -anchor nw
     $f.c create text 120 22 -text $help(about) -anchor nw -width 350
@@ -903,16 +940,16 @@ proc OpenConsole {} {
     }
 }
 
-proc ToggleBindEvents {} {
+proc ToggleFreeze {} {
     global ds9
 
     if {$ds9(freeze)} {
 	set ds9(freeze) 0
-	BindEventsCanvas
+	BindEventsCanvasItems
 	BindEventsPanner
     } else {
 	set ds9(freeze) 1
-	UnBindEventsCanvas
+	UnBindEventsCanvasItems
 	UnBindEventsPanner
     }
 }
@@ -932,10 +969,31 @@ proc ChangeMode {} {
     }
 
     UpdateRegionMenu
+    UpdateIllustrateMenu
 
     RefreshInfoBox $current(frame)
     PixelTableClearDialog
 
+    # illustrate
+    if {$current(mode,illustrate)} {
+	set current(mode,illustrate) 0
+
+	IllustrateModeEnd
+	BindEventsCanvas
+	BindEventsCanvasItems
+    }
+
+    switch -- $current(mode) {
+	illustrate {
+	    set current(mode,illustrate) 1
+	    UnBindEventsCanvas
+	    UnBindEventsCanvasItems
+	    IllustrateModeBegin
+	}
+	default {}
+    }
+
+    # cursor
     switch -- $current(mode) {
 	none -
 	pointer -
@@ -956,7 +1014,8 @@ proc ChangeMode {} {
 	crop {SetCursor {}}
 	examine {SetCursor target}
 	iexam {}
-	3d {SetCursor {}}
+	3d -
+	illustrate {SetCursor {}}
     }
 }
 
@@ -1539,7 +1598,7 @@ proc CursorCmd {x y} {
     }
 
     switch -- $current(mode) {
-	none {$current(frame) warp $x $y}
+	none {WarpCursor $current(frame) $x $y}
 	pointer -
 	region -
 	catalog -
@@ -1552,7 +1611,8 @@ proc CursorCmd {x y} {
 	crop -
 	examine -
 	iexam -
-	3d {}
+	3d -
+	illustrate {}
     }
 }
 
